@@ -7,8 +7,7 @@ import (
 	"os/exec"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 )
 
 type xorEncryption struct {
@@ -42,20 +41,20 @@ func (e *xorEncryption) EncryptedSuffix() string {
 }
 
 func (e *xorEncryption) xorWithKey(input []byte) []byte {
-	output := make([]byte, 0, len(input))
-	for _, b := range input {
-		output = append(output, b^e.key)
+	output := make([]byte, len(input))
+	for i, b := range input {
+		output[i] = b ^ e.key
 	}
 	return output
 }
 
 func lookPathOrSkip(t *testing.T, file string) string {
 	t.Helper()
-	command, err := exec.LookPath(file)
+	command, err := LookPath(file)
 	if errors.Is(err, exec.ErrNotFound) {
 		t.Skipf("%s not found in $PATH", file)
 	}
-	require.NoError(t, err)
+	assert.NoError(t, err)
 	return command
 }
 
@@ -65,17 +64,17 @@ func testEncryptionDecryptToFile(t *testing.T, encryption Encryption) {
 		expectedPlaintext := []byte("plaintext\n")
 
 		actualCiphertext, err := encryption.Encrypt(expectedPlaintext)
-		require.NoError(t, err)
-		require.NotEmpty(t, actualCiphertext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualCiphertext)
 		assert.NotEqual(t, expectedPlaintext, actualCiphertext)
 
 		plaintextAbsPath := NewAbsPath(t.TempDir()).JoinString("plaintext")
 
-		require.NoError(t, encryption.DecryptToFile(plaintextAbsPath, actualCiphertext))
+		assert.NoError(t, encryption.DecryptToFile(plaintextAbsPath, actualCiphertext))
 
 		actualPlaintext, err := os.ReadFile(plaintextAbsPath.String())
-		require.NoError(t, err)
-		require.NotEmpty(t, actualPlaintext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualPlaintext)
 		assert.Equal(t, expectedPlaintext, actualPlaintext)
 	})
 }
@@ -86,13 +85,13 @@ func testEncryptionEncryptDecrypt(t *testing.T, encryption Encryption) {
 		expectedPlaintext := []byte("plaintext\n")
 
 		actualCiphertext, err := encryption.Encrypt(expectedPlaintext)
-		require.NoError(t, err)
-		require.NotEmpty(t, actualCiphertext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualCiphertext)
 		assert.NotEqual(t, expectedPlaintext, actualCiphertext)
 
 		actualPlaintext, err := encryption.Decrypt(actualCiphertext)
-		require.NoError(t, err)
-		require.NotEmpty(t, actualPlaintext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualPlaintext)
 		assert.Equal(t, expectedPlaintext, actualPlaintext)
 	})
 }
@@ -103,23 +102,23 @@ func testEncryptionEncryptFile(t *testing.T, encryption Encryption) {
 		expectedPlaintext := []byte("plaintext\n")
 
 		plaintextAbsPath := NewAbsPath(t.TempDir()).JoinString("plaintext")
-		require.NoError(t, os.WriteFile(plaintextAbsPath.String(), expectedPlaintext, 0o666))
+		assert.NoError(t, os.WriteFile(plaintextAbsPath.String(), expectedPlaintext, 0o666))
 
 		actualCiphertext, err := encryption.EncryptFile(plaintextAbsPath)
-		require.NoError(t, err)
-		require.NotEmpty(t, actualCiphertext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualCiphertext)
 		assert.NotEqual(t, expectedPlaintext, actualCiphertext)
 
 		actualPlaintext, err := encryption.Decrypt(actualCiphertext)
-		require.NoError(t, err)
-		require.NotEmpty(t, actualPlaintext)
+		assert.NoError(t, err)
+		assert.NotZero(t, actualPlaintext)
 		assert.Equal(t, expectedPlaintext, actualPlaintext)
 	})
 }
 
 func TestXOREncryption(t *testing.T) {
 	testEncryption(t, &xorEncryption{
-		key: byte(rand.Int() + 1),
+		key: byte(rand.Intn(255) + 1),
 	})
 }
 
