@@ -20,7 +20,7 @@ func (c *Config) newCatConfigCmd() *cobra.Command {
 }
 
 func (c *Config) runCatConfigCmd(cmd *cobra.Command, args []string) error {
-	data, err := c.baseSystem.ReadFile(c.configFileAbsPath)
+	data, err := c.baseSystem.ReadFile(c.getConfigFileAbsPath())
 	if err != nil {
 		return err
 	}
