@@ -438,6 +438,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"gitHubLatestRelease":          c.gitHubLatestReleaseTemplateFunc,
 		"gitHubLatestReleaseAssetURL":  c.gitHubLatestReleaseAssetURLTemplateFunc,
 		"gitHubLatestTag":              c.gitHubLatestTagTemplateFunc,
+		"gitHubRelease":                c.gitHubReleaseTemplateFunc,
+		"gitHubReleaseAssetURL":        c.gitHubReleaseAssetURLTemplateFunc,
 		"gitHubReleases":               c.gitHubReleasesTemplateFunc,
 		"gitHubTags":                   c.gitHubTagsTemplateFunc,
 		"glob":                         c.globTemplateFunc,
@@ -475,8 +477,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"output":                       c.outputTemplateFunc,
 		"pass":                         c.passTemplateFunc,
 		"passFields":                   c.passFieldsTemplateFunc,
-		"passhole":                     c.passholeTemplateFunc,
 		"passRaw":                      c.passRawTemplateFunc,
+		"passhole":                     c.passholeTemplateFunc,
 		"pruneEmptyDicts":              c.pruneEmptyDictsTemplateFunc,
 		"quoteList":                    c.quoteListTemplateFunc,
 		"rbw":                          c.rbwTemplateFunc,
