@@ -10,7 +10,7 @@ import (
 	"path/filepath"
 
 	"github.com/coreos/go-semver/semver"
-	"github.com/google/go-github/v62/github"
+	"github.com/google/go-github/v63/github"
 	vfs "github.com/twpayne/go-vfs/v5"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
@@ -85,12 +85,7 @@ func (c *Config) snapRefresh() error {
 	return errUnsupportedUpgradeMethod
 }
 
-func (c *Config) upgradeUNIXPackage(
-	ctx context.Context,
-	version *semver.Version,
-	rr *github.RepositoryRelease,
-	useSudo bool,
-) error {
+func (c *Config) upgradeUNIXPackage(_ context.Context, _ *semver.Version, _ *github.RepositoryRelease, _ bool) error {
 	return errUnsupportedUpgradeMethod
 }
 
